@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from hcloud.core.client import BoundModelBase, ClientEntityBase, GetEntityByNameMixin
 
 from hcloud.isos.domain import Iso
@@ -9,7 +8,7 @@ class BoundIso(BoundModelBase):
 
 
 class IsosClient(ClientEntityBase, GetEntityByNameMixin):
-    results_list_attribute_name = 'isos'
+    results_list_attribute_name = "isos"
 
     def get_by_id(self, id):
         # type: (int) -> BoundIso
@@ -18,14 +17,17 @@ class IsosClient(ClientEntityBase, GetEntityByNameMixin):
         :param id: int
         :return: :class:`BoundIso <hcloud.isos.client.BoundIso>`
         """
-        response = self._client.request(url="/isos/{iso_id}".format(iso_id=id), method="GET")
-        return BoundIso(self, response['iso'])
+        response = self._client.request(
+            url="/isos/{iso_id}".format(iso_id=id), method="GET"
+        )
+        return BoundIso(self, response["iso"])
 
-    def get_list(self,
-                 name=None,      # type: Optional[str]
-                 page=None,      # type: Optional[int]
-                 per_page=None,  # type: Optional[int]
-                 ):
+    def get_list(
+        self,
+        name=None,  # type: Optional[str]
+        page=None,  # type: Optional[int]
+        per_page=None,  # type: Optional[int]
+    ):
         # type: (...) -> PageResults[List[BoundIso], Meta]
         """Get a list of ISOs
 
@@ -39,14 +41,14 @@ class IsosClient(ClientEntityBase, GetEntityByNameMixin):
         """
         params = {}
         if name is not None:
-            params['name'] = name
+            params["name"] = name
         if page is not None:
-            params['page'] = page
+            params["page"] = page
         if per_page is not None:
-            params['per_page'] = per_page
+            params["per_page"] = per_page
 
         response = self._client.request(url="/isos", method="GET", params=params)
-        isos = [BoundIso(self, iso_data) for iso_data in response['isos']]
+        isos = [BoundIso(self, iso_data) for iso_data in response["isos"]]
         return self._add_meta_to_result(isos, response)
 
     def get_all(self, name=None):
